==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/gadu_protocol/services/user-data/gadu-user-data-service.h <==
/*
 * %kadu copyright begin%
 * Copyright 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "protocols/services/account-service.h"

#include <QtCore/QPointer>

struct gg_event_user_data;
struct gg_event_user_data_user;

class AvatarManager;
class ContactManager;

class GaduUserDataService : public AccountService
{
	Q_OBJECT

public:
	explicit GaduUserDataService(Account account, QObject *parent = nullptr);
	virtual ~GaduUserDataService();

	void setAvatarManager(AvatarManager *avatarManager);
	void setContactManager(ContactManager *contactManager);

	void handleUserDataEvent(const gg_event_user_data &userData);

private:
	QPointer<AvatarManager> m_avatarManager;
	QPointer<ContactManager> m_contactManager;

	void handleUserDataItem(const gg_event_user_data_user &userDataUser, bool update);

};

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/gadu_protocol/services/user-data/gadu-user-data-service.h <==
/*
 * %kadu copyright begin%
 * Copyright 2015 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "protocols/services/account-service.h"

#include <QtCore/QPointer>
#include <injeqt/injeqt.h>

struct gg_event_user_data;
struct gg_event_user_data_user;

class AvatarManager;
class ContactManager;

class GaduUserDataService : public AccountService
{
	Q_OBJECT

public:
	explicit GaduUserDataService(Account account, QObject *parent = nullptr);
	virtual ~GaduUserDataService();

	void handleUserDataEvent(const gg_event_user_data &userData);

private:
	QPointer<AvatarManager> m_avatarManager;
	QPointer<ContactManager> m_contactManager;

	void handleUserDataItem(const gg_event_user_data_user &userDataUser, bool update);

private slots:
	INJEQT_SET void setAvatarManager(AvatarManager *avatarManager);
	INJEQT_SET void setContactManager(ContactManager *contactManager);

};
